% Calculate low pass filter response for fast adc buffer amp design
% Simple 1st order active + 1 passive stage. 
% H(f) = (Rf/Rg) x (1 / (1 + j2Pif x Rf x Cf)) x (1 / (1 + j2Pif x 2 x Ro x Co))
% More complex 3rd order filter
% H(f) = [(Rf / Rg) / -(f / FSF)^2 + (1/Q)(jf / FSF) + 1) x (1 / (1 + j2Pif x 2 x Ro x Co)
% where FSF = 1 / (2Pi((2 x Rf1 x Rf2 x Cf1 x Cf2)^-1) 
% and     Q = ((2 x Rf1 x Rf2 x Cf1 x Cf2)^-1) / (Rf2 x Cf1 + Rf1 x Cf1 + (Rf1/Rg x Cf1)


% Peter Moore 21 - December - 2001

% Input capacitance of AD converter
Ca=16E-12;
% feed back component values
Cf1=56E-12;
Cf2=100E-12;
Rf1=309;
Rf2=1240;
% gain component value
Rg=1240;
% passive output component values
Ro=20;
Co=16E-12;
% Plot range in Hz
LL = 1;
UL = 5000000;
% Plot resolution
R = 100;

% Start processing
K=Rf1/Rg;
Cb=Co+Ca;
np = fix((UL - LL) / R);
p = linspace(LL,UL,(np+1));
q1 = 1 ./ (1 + ((2j*pi).*p) * Rf1 * Cf1);
q2 = 1 ./ (1 + ((2j*pi).*p) * 2 * Ro * Cb);
qr = log10(K .* (q1 .* q2)) * 20;
FSF=1/(2*pi*sqrt(Rf1*Rf2*Cf1*Cf2));
Q=sqrt(2*Rf1*Rf2*Cf1*Cf2) / (Rf2*Cf1+Rf1*Cf1+K*Rf2*Cf1);
r1 = K ./ ((-1.*(p./FSF).^2)+(1/Q*(j.*p./FSF)+1));
rr = log10(r1 .* q2) * 20;
plot(p,qr,p,rr);
% End processing